@@ -35,8 +35,12 @@
 #include "global.h"
 #include "proto.h"
 #include "vars.h"
-#include "ship.h"
+
+#ifdef __OpenBSD__
+#include "ieeefp.h"
+#else
 #include "fenv.h"
+#endif
 
 int ThisMessageTime;
 float LastGotIntoBlastSound = 2;
@@ -81,7 +85,21 @@ main (int argc, char * argv[])
 {
     int i;
     int PlayerNum;
+	DIR *tmp_dir;
     
+#if ENABLE_NLS
+	setlocale(LC_MESSAGES, "");
+	tmp_dir = opendir("../po");
+	if(tmp_dir != NULL) 
+	{
+		bindtextdomain(LOCALE_PACKAGE, "../po");
+		closedir(tmp_dir);
+	}
+	else 
+		bindtextdomain(LOCALE_PACKAGE, LOCALE_DIR);
+	textdomain(LOCALE_PACKAGE);
+#endif
+
     //--------------------
     // First we issue some message, that should appear in the debug log for
     // windows users.
@@ -122,14 +140,14 @@ better than nothing.  Thanks anyway for your interest in FreedroidRPG.\n\
     sound_on = TRUE;	 // default value, can be overridden by command-line 
     use_open_gl = TRUE;	 // default value, can be overridden by command-line 
     debug_level = -1;      // -1: shut up all debug ... 0=no debug 1=first debug level (at the moment=all) 
-    fullscreen_on = TRUE;  // use X11-window or full screen 
+    GameConfig . fullscreen_on = TRUE;  // use X11-window or full screen 
     joy_sensitivity = 1;
     mouse_control = TRUE;
     classic_user_rect = FALSE;
     
-    ParseCommandLine ( argc , argv ); 
     
-    InitFreedroid ();   // Initialisation of global variables and arrays
+    InitFreedroid ( argc, argv);   // Initialisation of global variables and arrays
+    
 
     while (!QuitProgram)
     {
@@ -407,12 +425,19 @@ UpdateCountersForThisFrame ( int player_num )
     if ( Me [ player_num ] . energy > Me [ player_num ] . maxenergy )
 	    Me [ player_num ] . energy = Me [ player_num ] . maxenergy;
 
-    Me [ player_num ] . mana += Me [ player_num ] . mana_recovery_rate * latest_frame_time;
-    if ( Me [ player_num ] . mana > Me [ player_num ] . maxmana )
-	    Me [ player_num ] . mana = Me [ player_num ] . maxmana;
-    if ( Me [ player_num ] . mana < 0 )
-	    Me [ player_num ] . mana = 0;
+    Me [ player_num ] . temperature -= Me [ player_num ] . cooling_rate * latest_frame_time;
+    if ( Me [ player_num ] . temperature < 0 )
+	    Me [ player_num ] . temperature = 0;
     
+    if ( Me [ player_num ] . temperature > Me [ player_num] . max_temperature ) //overheat, lose life
+	    {
+	    if ( Me [ player_num ] . old_temperature < Me [ player_num ] . max_temperature ) 
+		append_new_game_message(_("Overheating!"));
+	    Me [ player_num ] . energy -= ( Me [ player_num ] . temperature - Me[player_num].max_temperature ) * latest_frame_time / 10;
+	    }
+    
+    Me [ player_num ] . old_temperature = Me [ player_num ] . temperature;
+
     if ( Me [ player_num ] . weapon_swing_time != (-1) ) Me [ player_num ] . weapon_swing_time += latest_frame_time;
     if ( Me [ player_num ] . got_hit_time != (-1) ) Me [ player_num ] . got_hit_time += latest_frame_time;
     
@@ -424,12 +449,17 @@ UpdateCountersForThisFrame ( int player_num )
     if ( Me [ player_num ] . busy_time == 0)
 	{
 	if ( Me [ player_num ] . busy_type == WEAPON_RELOAD )
-		append_new_game_message("Weapon reloaded");
+		append_new_game_message(_("Weapon reloaded"));
 	Me [ player_num ] . busy_type = NONE;
 	}
 
-    // DebugPrintf ( -1000 , "\nfirewait; %f." , Me [ 0 ] . firewait );
-    
+    if ( Me [ player_num ] . paralyze_duration )
+	Me [ player_num ] . paralyze_duration -= latest_frame_time;  
+    if ( Me [ player_num ] . slowdown_duration )
+	Me [ player_num ] . slowdown_duration -= latest_frame_time;    
+    if ( Me [ player_num ] . paralyze_duration < 0)  Me [ player_num ] . paralyze_duration = 0;
+    if ( Me [ player_num ] . slowdown_duration < 0)  Me [ player_num ] . slowdown_duration = 0;
+
     //--------------------
     // In order to know when a level can finally be respawned with
     // enemies, we keep track to the time spent actually in the game, i.e.
