@@ -36,7 +36,6 @@
 #include "global.h"
 #include "proto.h"
 #include "takeover.h"
-#include "ship.h"
 #include "map.h"
 
 Uint32 cur_time;  		// current time in ms 
@@ -300,27 +299,12 @@ Takeover ( int enemynum )
 	    if ( Me [ 0 ] . health > Me [ 0 ] . maxenergy ) 
 		Me [ 0 ] . health = Me [ 0 ] . maxenergy;
 	    
-	    //--------------------
-	    // We add the victims security clearance to our own list of 
-	    // availabe security clearances.
-	    //
-	    for ( ClearanceIndex = 0 ; ClearanceIndex < MAX_CLEARANCES ; ClearanceIndex ++ )
-	    {
-		if ( Me [ 0 ] . clearance_list [ ClearanceIndex ] == 0 )
-		{
-		    Me [ 0 ] . clearance_list [ ClearanceIndex ] = AllEnemys [ enemynum ] . type ;
-		    // SetNewBigScreenMessage ( "Clearance obtained" );
-		    SetNewBigScreenMessage ( "Bot Reprogrammed" );
-		    break;
-		}
-	    }
-	    
 	    Me [ 0 ] . type = AllEnemys [ enemynum ] . type;
 	    Me [ 0 ] . marker = AllEnemys [ enemynum ] . marker;
 
 	    reward = Druidmap [ AllEnemys [ enemynum ] . type ] . experience_reward * 3 ;
 	    Me [ 0 ] . Experience += reward;
-	    sprintf ( game_message_text , "For taking control of your enemy, you receive %d experience." ,
+	    sprintf ( game_message_text , _("For taking control of your enemy, you receive %d experience."),
 		      reward );
 	    append_new_game_message ( game_message_text );
 
@@ -367,9 +351,9 @@ Takeover ( int enemynum )
 	    // very much relevant any more in the freedroidRPG variant....
 	    //
 	    if ( LeaderColor != YourColor )	// only won because of InvincibleMode 
-		message = "You cheat";
+		message = _("You cheat");
 	    else				// won the proper way 
-		message = "Complete";
+		message = _("Complete");
 	    
 	    //--------------------
 	    // Ok.  The whole takeover is done now.  We can return...
@@ -379,7 +363,7 @@ Takeover ( int enemynum )
 	else if ( LeaderColor == OpponentColor )
 	{
 	    Takeover_Game_Lost_Sound ();
-	    message = "Rejected";
+	    message = _("Rejected");
 	    Me [ 0 ] . energy *= 0.5 ;
 	    AllEnemys [ enemynum ] . energy = Druidmap [ AllEnemys [ enemynum ] . type ] . maxenergy ;
 	    FinishTakeover = TRUE;
@@ -387,7 +371,7 @@ Takeover ( int enemynum )
 	else
 	{
 	    Takeover_Game_Deadlock_Sound ();
-	    message = "Deadlock";
+	    message = _("Deadlock");
 	}			// LeadColor == DRAW	
 
 	ShowPlayground ();
@@ -450,7 +434,7 @@ ChooseColor (void)
 	}
 	
 	countdown--; // Count down 
-	sprintf (count_text, "Color-%d", countdown);
+	sprintf (count_text, _("Color-%d"), countdown);
 	
 	ShowPlayground ();
 	to_show_banner (count_text, NULL);
@@ -487,7 +471,7 @@ PlayGame (void)
   int up, down, set; 
   int up_counter, down_counter; 
 
-  sprintf (count_text, "Subliminal");   /* Make sure a value gets assigned to count_text */
+  sprintf (count_text, _("Subliminal"));   /* Make sure a value gets assigned to count_text */
   count_tick_len = 100;   /* countdown in 1/10 second steps */
   move_tick_len  = 60;    /* allow motion at this tick-speed in ms */
   
@@ -514,7 +498,7 @@ PlayGame (void)
       if (!down) down_counter =0;
 
       /* allow for a WIN-key that give immedate victory */
-      if ( WPressed () && CtrlWasPressed () && AltWasPressed () )
+      if ( WPressed () && CtrlPressed () && AltPressed () )
 	{
 	  LeaderColor = YourColor;   /* simple as that */
 	  return;  /* leave now, to avoid changing of LeaderColor! */
@@ -524,7 +508,7 @@ PlayGame (void)
 	{
 	  prev_count_tick += count_tick_len;  /* set for next countdown tick */
 	  countdown--;
-	  sprintf (count_text, "Finish-%d", countdown);
+	  sprintf (count_text, _("Finish-%d"), countdown);
 
 	  if (countdown == 0)
 	    FinishTakeover = TRUE;
@@ -1767,7 +1751,7 @@ to_show_banner (const char* left, const char* right)
 
   if ( right == NULL )
     {
-      sprintf ( dummy , "Score" );
+      sprintf ( dummy , _("Score"));
       right = dummy;
     }
 
