@@ -60,7 +60,7 @@ unsigned int StoreTextFG;
  *
  * ---------------------------------------------------------------------- */
 void
-show_backgrounded_label_at_pixel_position ( char* LabelText , float fill_status , int pos_x , int pos_y )
+show_backgrounded_label_at_pixel_position ( char* LabelText , int pos_x , int pos_y )
 {
     SDL_Rect background_rect;
     
@@ -86,7 +86,7 @@ show_backgrounded_label_at_map_position ( char* LabelText , float fill_status ,
     float zoom_factor = (zoom_is_on ? 1.0 / LEVEL_EDITOR_ZOOM_OUT_FACT : 1.0);
     
     translate_map_point_to_screen_pixel ( pos_x , pos_y , &pixel_x, &pixel_y, zoom_factor );
-    show_backgrounded_label_at_pixel_position ( LabelText , fill_status , pixel_x , pixel_y );
+    show_backgrounded_label_at_pixel_position ( LabelText , pixel_x , pixel_y );
     
 }; // void show_backgrounded_label_at_map_position ( char* LabelText , float fill_status , float pos_x , float pos_y )
 
@@ -190,23 +190,23 @@ EnemyHitByBulletText( int Enum )
 	switch (MyRandom(4))
 	{
 	    case 0:
-		ThisRobot->TextToBeDisplayed="Unhandled exception fault.  Press ok to reboot.";
+		ThisRobot->TextToBeDisplayed=_("Unhandled exception fault.  Press ok to reboot.");
 		break;
 	    case 1:
-		ThisRobot->TextToBeDisplayed="System fault. Please buy a newer version.";
+		ThisRobot->TextToBeDisplayed=_("System fault. Please buy a newer version.");
 		break;
 	    case 2:
-		ThisRobot->TextToBeDisplayed="System error. Might be a virus.";
+		ThisRobot->TextToBeDisplayed=_("System error. Might be a virus.");
 		break;
 	    case 3:
-		ThisRobot->TextToBeDisplayed="System error. Pleae buy an upgrade from MS.";
+		ThisRobot->TextToBeDisplayed=_("System error. Please buy an upgrade from MS.");
 		break;
 	    case 4:
-		ThisRobot->TextToBeDisplayed="System error. Press any key to reboot.";
+		ThisRobot->TextToBeDisplayed=_("System error. Press any key to reboot.");
 		break;
 	}
     else
-	ThisRobot->TextToBeDisplayed="Aargh, I got hit.  Ugh, I got a bad feeling...";
+	ThisRobot->TextToBeDisplayed=_("Aargh, I got hit.  Ugh, I got a bad feeling...");
 }; // void EnemyHitByBullet( int Enum );
 
 /* ----------------------------------------------------------------------
@@ -224,17 +224,17 @@ EnemyInfluCollisionText ( int Enum )
     
     if ( ThisRobot->is_friendly )
     {
-	ThisRobot->TextToBeDisplayed="Ah, good, that we have an open collision avoiding standard, isn't it.";
+	ThisRobot->TextToBeDisplayed=_("Ah, good, that we have an open collision avoiding standard, isn't it.");
     }
     else
     {
 	switch ( MyRandom ( 1 ) )
 	{
 	    case 0:
-		ThisRobot->TextToBeDisplayed="Hey, I'm from MS! Walk outa my way!";
+		ThisRobot->TextToBeDisplayed=_("Hey, I'm from MS! Walk outa my way!");
 		break;
 	    case 1:
-		ThisRobot->TextToBeDisplayed="Hey, I know the big MS boss! You better go.";
+		ThisRobot->TextToBeDisplayed=_("Hey, I know the big MS boss! You better go.");
 		break;
 	}
     }
@@ -256,11 +256,11 @@ AddStandingAndAimingText ( int Enum )
     
     if ( ( fabsf ( Me [ 0 ] . speed . x ) < 1 ) && ( fabsf ( Me [ 0 ] . speed . y ) < 1 ) )
     {
-	ThisRobot->TextToBeDisplayed="Yeah, stay like that, haha.";
+	ThisRobot->TextToBeDisplayed=_("Yeah, stay like that, haha.");
     }
     else
     {
-	ThisRobot->TextToBeDisplayed="Stand still while I aim at you.";
+	ThisRobot->TextToBeDisplayed=_("Stand still while I aim at you.");
     }
     
 }; // void AddStandingAndAimingText( int Enum )
@@ -282,25 +282,25 @@ AddInfluBurntText( void )
     switch ( FinalTextNr )
     {
 	case 0:
-	    Me[0].TextToBeDisplayed="Aaarrgh, aah, that burnt me!";
+	    Me[0].TextToBeDisplayed=_("Aaarrgh, aah, that burnt me!");
 	    break;
 	case 1:
-	    Me[0].TextToBeDisplayed="Hell, that blast was hot!";
+	    Me[0].TextToBeDisplayed=_("Hell, that blast was hot!");
 	    break;
 	case 2:
-	    Me[0].TextToBeDisplayed="Ghaart, I hate to stain my chassis like that.";
+	    Me[0].TextToBeDisplayed=_("Ghaart, I hate to stain my chassis like that.");
 	    break;
 	case 3:
-	    Me[0].TextToBeDisplayed="Oh no!  I think I've burnt a cable!";
+	    Me[0].TextToBeDisplayed=_("Oh no!  I think I've burnt a cable!");
 	    break;
 	case 4:
-	    Me[0].TextToBeDisplayed="Oh no, my poor transfer connectors smolder!";
+	    Me[0].TextToBeDisplayed=_("Oh no, my poor transfer connectors smolder!");
 	    break;
 	case 5:
-	    Me[0].TextToBeDisplayed="I hope that didn't melt any circuits!";
+	    Me[0].TextToBeDisplayed=_("I hope that didn't melt any circuits!");
 	    break;
 	case 6:
-	    Me[0].TextToBeDisplayed="So that gives some more black scars on me ol' dented chassis!";
+	    Me[0].TextToBeDisplayed=_("So that gives some more black scars on me ol' dented chassis!");
 	    break;
 	default:
 	    printf("\nError in AddInfluBurntText! That shouldn't be happening.");
@@ -331,7 +331,7 @@ SetTextCursor ( int x , int y )
  *
  * ----------------------------------------------------------------- */
 int
-ScrollText (char *Text, int startx, int starty, int EndLine , int background_code )
+ScrollText (char *Text, int startx, int starty, int background_code )
 {
     int Number_Of_Line_Feeds = 0;	// number of lines used for the text
     char *textpt;			// mobile pointer to the text
@@ -604,10 +604,11 @@ DisplayBigScreenMessage( void )
 int
 DisplayText ( const char *Text, int startx, int starty, const SDL_Rect *clip , float text_stretch )
 {
-    char *tmp;	// mobile pointer to the current position in the string to be printed
+    unsigned char *tmp;	// mobile pointer to the current position in the string to be printed
     SDL_Rect Temp_Clipping_Rect; // adding this to prevent segfault in case of NULL as parameter
     SDL_Rect store_clip;
-    short int line_nb = 1;
+    short int nblines = 1;
+
     //--------------------
     // We position the internal text cursor on the right spot for
     // the first character to be printed.
@@ -638,29 +639,44 @@ DisplayText ( const char *Text, int startx, int starty, const SDL_Rect *clip , f
 	Temp_Clipping_Rect.w=GameConfig . screen_width;
 	Temp_Clipping_Rect.h=GameConfig . screen_height;
     }
+
     
     //--------------------
     // Now we can start to print the actual text to the screen.
     //
     // The running text pointer must be initialized.
     //
-    tmp = (char*) Text;  // this is no longer a 'const' char*, but only a char*
+    tmp = (unsigned char*) Text;  // this is no longer a 'const' char*, but only a char*
     while ( *tmp && ( MyCursorY < clip -> y + clip -> h ) )
     {
 	if ( *tmp == '\n' )
 	{
 	    MyCursorX = clip->x;
 	    MyCursorY += FontHeight ( GetCurrentFont() ) * text_stretch ;
-	    line_nb ++;
+	    nblines ++;
 	}
-	else
-	    DisplayChar (*tmp);
+	else 
+	    {
+	    if ( MyCursorY > clip -> y - FontHeight ( GetCurrentFont() ) * text_stretch) 
+      	        DisplayChar (*tmp);
+	    else 
+		{
+                MyCursorX += CharWidth ( GetCurrentFont() , *tmp) ;                                
+		switch ( * tmp ) 
+		    {
+		    case 1: SetCurrentFont(Red_BFont); break;
+		    case 2: SetCurrentFont(Blue_BFont); break;
+		    case 3: SetCurrentFont(FPS_Display_BFont); break;
+		    }
+		}
+	    }
+
 	
 	tmp++;
 	
         if(ImprovedCheckLineBreak( tmp , clip , text_stretch ) == 1)   // dont write over right border 
 		{ /*THE CALL ABOVE HAS DONE THE CARRIAGE RETURN FOR US !!!*/
-		line_nb++;
+		nblines ++;
 		}
 	
     }
@@ -675,7 +691,7 @@ DisplayText ( const char *Text, int startx, int starty, const SDL_Rect *clip , f
 	 ( ( MyCursorY < clip -> y ) || ( starty > clip -> y + clip -> h ) ) )
 	return FALSE;  // no text was written inside clip 
     else
-	return line_nb; 
+	return nblines; 
     
 }; // int DisplayText(...)
 
@@ -686,7 +702,7 @@ DisplayText ( const char *Text, int startx, int starty, const SDL_Rect *clip , f
 void
 DisplayChar (unsigned char c)
 {
-
+    
     if ( c == 1 ) 
     {
 	SetCurrentFont ( Red_BFont );
@@ -703,6 +719,10 @@ DisplayChar (unsigned char c)
 	return;
     }
     
+    // stupid kerning hack, to get smooth font, but tighter look
+    int kerning = 0;
+    if (GetCurrentFont()==FPS_Display_BFont || GetCurrentFont()==Blue_BFont || GetCurrentFont()==Red_BFont) kerning = -2;
+    
     if( c < ' ' || c > GetCurrentFont()->number_of_chars-1){
         printf("l: %u of %u \n",c,GetCurrentFont()->number_of_chars);
        c = '.';
@@ -716,7 +736,7 @@ DisplayChar (unsigned char c)
     // After the char has been displayed, we must move the cursor to its
     // new position.  That depends of course on the char displayed.
     //
-    MyCursorX += CharWidth ( GetCurrentFont() , c);
+    MyCursorX += CharWidth ( GetCurrentFont() , c) +kerning;
     
 }; // void DisplayChar(...)
 
